package com.xinhuan.lightlpr.api;

//import androidx.appcompat.app.AppCompatActivity;

public class LLPR {

    static int MAX_CODES = 12;
    static int MAX_PLATE_NO_BYTES = 64;

    public  interface Callback {
        /**
         * 当有车牌被识别时，触发这个函数，参数<em>plateBasicInfo</em>包含了车牌信息。
         * Java端通过实现这个接口函数和<em>regCallbackClassName</em>
         */
        void onRecogPlate(PlateBasicInfo plateBasicInfo);
    }

    // Used to load the 'native-lib' library on application startup.
    static {
        System.loadLibrary("light_lpr_api_wrapper");
    }

    public static native int initClientApi(String localIP, int localPort);
    public static native void regCallback(String className, Object object);
    public static native int connectDevice(String deviceIP);
    public static native void closeClientApi();

    public static native Speed newSpeed();
    public static native void setImageDir(String dir);

    /**
     * 切换WDR
     * @param deviceIP 相机IP
     * @param wdrStatus wdrStatus 0 close WDR, 1 open WDR
     */
    public static native void switchWDR(String deviceIP, int wdrStatus);

    /**
     * 触发抓拍，抓拍结果送入回调函数
     * @param deviceIP 相机IP
     */
    public static native void takeSnapshot(String deviceIP);

    /**
     * 设置识别框，xmin, ymin是识别框的左上顶点，xmax，ymax是右下顶点，采用相对坐标系，取值0-1之间，
     * 设置时需要保证xmin小于xmax, ymin小于ymax
     * @param deviceIP 相机IP
     * @param xmin 识别框左上顶点x轴坐标
     * @param ymin 识别框左上顶点y轴坐标
     * @param xmax 识别框右下顶点x轴坐标
     * @param ymax 识别框右下顶点y轴坐标
     */
    public static native void setAnchorBox(String deviceIP, float xmin, float ymin, float xmax, float ymax);

    /**
     * 设置识别框
     * @param deviceIP 相机IP
     * @param anchorBox @see AnchorBox
     */
    public static native  void setAnchorBoxNew(String deviceIP, AnchorBox anchorBox);


    /**
     * 获得相机当前的识别框参数
     * @param deviceIP
     * @return 调用成功返回AnchorBox对象, 调用失败，返回null
     */
    public static native AnchorBox getAnchorBox(String deviceIP);


    /**
     * 30s内重启相机
     * @param deviceIP
     */
    public static native void reboot(String deviceIP);


    /**
     * 获取设备信息
     * @param deviceIP
     * @return
     */
    public static native  DeviceInfo getDeviceInfo(String deviceIP);
}
