package com.xinhuan.lightlpr.demo;

import androidx.appcompat.app.AppCompatActivity;

import android.content.Context;
import android.os.Bundle;
import android.os.Handler;
import android.util.Log;
import android.view.View;
import android.widget.Button;
import android.widget.CompoundButton;
import android.widget.EditText;
import android.widget.Switch;
import android.widget.TextView;
import android.widget.Toast;

import static com.xinhuan.lightlpr.api.LLPR.*;

import com.xinhuan.lightlpr.api.AnchorBox;
import com.xinhuan.lightlpr.api.DeviceInfo;
import com.xinhuan.lightlpr.api.LLPR;
import com.xinhuan.lightlpr.api.PlateBasicInfo;
import com.xinhuan.lightlpr.api.PlateBox;


import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;
public class MainActivity extends AppCompatActivity implements LLPR.Callback {

  File dir;
  Context context;
  PlateBasicInfo plateBasicInfo;

  Handler mHandler = new Handler();

  boolean connected = false;

  public void onRecogPlate(PlateBasicInfo pbi) {
    plateBasicInfo = pbi;

    // MUST UPDATE VIEWS IN ANOTHER THREAD
    mHandler.post(new Runnable() {
      @Override
      public void run() {
        TextView tv_plateno = findViewById(R.id.tv_plateno);
        tv_plateno.setText("" + plateBasicInfo.plateNos);
        TextView tv_platecolor = findViewById(R.id.tv_platecolor);
        tv_platecolor.setText("" + plateBasicInfo.plateColor);
        TextView tv_prob = findViewById(R.id.tv_prob);
        tv_prob.setText("" + plateBasicInfo.prob);
        TextView tv_imagesize = findViewById(R.id.tv_imagesize);
        tv_imagesize.setText("" + plateBasicInfo.imageBufferSize);
        TextView tv_seq = findViewById((R.id.tv_seq));
        tv_seq.setText("" + plateBasicInfo.seq);
      }
    });


    PlateBox bb = plateBasicInfo.plateBox;
    Log.i("light-lpr-api", String.format("%s at (%f, %f, %f, %f) with prob: %f, image size: %d, camera IP: %s",
      plateBasicInfo.plateNos,
      bb.xmin, bb.ymin, bb.xmax, bb.ymax,
      plateBasicInfo.prob, plateBasicInfo.imageBufferSize, plateBasicInfo.cameraIP));

    try {
      File file = new File(dir, "test.jpg");
      FileOutputStream fos = new FileOutputStream(file);
      fos.write(pbi.imageBuffer, 0, plateBasicInfo.imageBufferSize);
      fos.close();
    }
    catch (IOException e) {
      Log.e("light-lpr-api", e.getMessage());
    }
  }

  @Override
  protected void onCreate(Bundle savedInstanceState) {
    super.onCreate(savedInstanceState);
    setContentView(R.layout.activity_main);


    context = getApplicationContext();
    // get current image dir
    dir = context.getExternalFilesDir("xinhuan");

    if (!dir.exists()) {
      if (!dir.mkdirs()) {
        Toast.makeText(this, "权限不足", Toast.LENGTH_LONG).show();
      }
    }

    regCallback(MainActivity.class.getName().replace(".", "/"), this);




    final EditText tvDeviceIP = findViewById(R.id.editText_deviceip);
    final EditText tvLocalIP = findViewById(R.id.editText_localip);
    final EditText tvLocalPort = findViewById(R.id.editText_localport);

    final TextView tvStatus = findViewById(R.id.textView_status);
    Button connect = findViewById(R.id.button_connect);


//        try {
//            String ip = InetAddress.getLocalHost().getHostAddress();
//            tvLocalIP.setText(ip);
//        }
//        catch (IOException e)
//        {
//            Toast.makeText(MainActivity.this, "cannot get local host ip" , Toast.LENGTH_LONG).show();
//        }


    connect.setOnClickListener(new View.OnClickListener() {
      public void onClick(View v) {
        int status = initClientApi(
          tvLocalIP.getText().toString(),
          Integer.parseInt(tvLocalPort.getText().toString()));
        if (status == 0) {
          tvStatus.setText("success");
        } else {
          tvStatus.setText("failed");
        }

        if (status == 0 )
        {
          String cameraIPs[] = tvDeviceIP.getText().toString().replace(" ", "").split(",");
          for (String cameraIP: cameraIPs)
          {
            if (connectDevice(cameraIP) != 0)
            {
              String msg = "connect camera failed, " + cameraIP;
              Toast.makeText(MainActivity.this, msg , Toast.LENGTH_LONG).show();
            }
          }
        }
      }
    });

    Button close = findViewById(R.id.button_close);
    close.setOnClickListener(new View.OnClickListener() {
      @Override
      public void onClick(View view) {
        closeClientApi();
        tvStatus.setText("");
      }
    });


    Button snapshot = findViewById(R.id.snapshot);
    snapshot.setOnClickListener(new View.OnClickListener() {
      @Override
      public void onClick(View view) {
        String cameraIPs[] = tvDeviceIP.getText().toString().replace(" ", "").split(",");
        for (String cameraIP: cameraIPs)
        {
          takeSnapshot(cameraIP);
        }
      }
    });


    Switch switchWDR = findViewById(R.id.switchWDR);
    switchWDR.setOnCheckedChangeListener(new CompoundButton.OnCheckedChangeListener(){
      @Override
      public void onCheckedChanged(CompoundButton compoundButton, boolean flag) {
        String cameraIPs[] = tvDeviceIP.getText().toString().replace(" ", "").split(",");
        for (String cameraIP: cameraIPs)
        {
          switchWDR(cameraIP, flag? 1: 0);
        }
      }
    });

    Button buttonSetAnchorBox = findViewById(R.id.button_setanchorbox);
    buttonSetAnchorBox.setOnClickListener(new View.OnClickListener() {
      @Override
      public void onClick(View view) {
        String cameraIPs[] = tvDeviceIP.getText().toString().replace(" ", "").split(",");
        for (String cameraIP: cameraIPs)
        {
          float xmin = 0.2f;
          float ymin = 0.2f;
          float xmax = 0.8f;
          float ymax = 0.8f;
          setAnchorBox(cameraIP, xmin, ymin, xmax, ymax);
        }

        if (cameraIPs.length > 0)
        {
          Toast.makeText(MainActivity.this, "set anchor boxes successfully!" , Toast.LENGTH_LONG).show();
        }
      }
    });

    Button buttonGetAnchorBox = findViewById(R.id.button_getanchorbox);
    buttonGetAnchorBox.setOnClickListener(new View.OnClickListener() {
      @Override
      public void onClick(View view) {
        String cameraIPs[] = tvDeviceIP.getText().toString().replace(" ", "").split(",");
        for (String cameraIP: cameraIPs)
        {
          AnchorBox anchorBox = getAnchorBox(cameraIP);
          if (anchorBox != null) {
            Log.i(MainActivity.class.getName(), String.format("anchor box: %.3f %.3f %.3f %.3f",
                    anchorBox.xmin, anchorBox.ymin, anchorBox.xmax, anchorBox.ymax));
          }
        }
      }
    });

    Button buttonReboot = findViewById(R.id.button_reboot);
    buttonReboot.setOnClickListener(new View.OnClickListener() {
      @Override
      public void onClick(View view) {
        String cameraIPs[] = tvDeviceIP.getText().toString().replace(" ", "").split(",");
        for (String cameraIP: cameraIPs)
        {
          reboot(cameraIP);
        }

        if (cameraIPs.length > 0)
        {
          Toast.makeText(MainActivity.this, "cameras will reboot in 30s!" , Toast.LENGTH_LONG).show();
        }
      }
    });


    Button buttonGetDeviceInfo = findViewById(R.id.button_getdeviceinfo);
    buttonGetDeviceInfo.setOnClickListener(new View.OnClickListener() {
      @Override
      public void onClick(View view) {
        String cameraIPs[] = tvDeviceIP.getText().toString().replace(" ", "").split(",");
        for (String cameraIP: cameraIPs)
        {
          DeviceInfo deviceInfo = getDeviceInfo(cameraIP);
          if (deviceInfo != null)
          {
            Log.i(MainActivity.class.getName(),
                    String.format("device name: %s, IP: %s, firmware: %s, version: %s, productNo: %s, startup: %d",
                            deviceInfo.deviceName,
                            deviceInfo.ip,
                            deviceInfo.firmware,
                            deviceInfo.version,
                            deviceInfo.productNo,
                            deviceInfo.startup));
          }
        }
      }
    });
  }
}
